@@ -8,69 +8,45 @@ import yaml
 from simplejson import JSONDecodeError
 
 from neoload_cli_lib import rest_crud, cli_exception, tools, config_global
-from neoload_cli_lib.name_resolver import Resolver
 
 __conf_name = "neoload-cli"
 __version = "1.0"
 __author = "neotys"
 __config_dir = appdirs.user_data_dir(__conf_name, __author, __version)
-__config_file = os.path.join(__config_dir, "config.yaml")
+__local_file = ".neoload_cli.yaml"
+CONFIG_FILE = __local_file if os.path.exists(__local_file) else os.path.join(__config_dir, "config.yaml")
 __yaml_schema_file = os.path.join(__config_dir, "yaml_schema.json")
 
 __no_write = False
 
 
 def do_logout():
-    global __user_data_singleton
-    __user_data_singleton = None
-    if os.path.exists(__config_file):
-        os.remove(__config_file)
+    UserData.clean()
+    if os.path.exists(CONFIG_FILE):
+        os.remove(CONFIG_FILE)
 
 
 def get_user_data(throw=True):
-    if __user_data_singleton is None and throw:
+    instance = UserData.get_instance()
+    if instance is None and throw:
         raise cli_exception.CliException("You aren't logged. Please use command \"neoload login\" first")
-    return __user_data_singleton
+    return instance
 
 
-def do_login(token, url, no_write, ssl_cert=''):
+def do_login(token, url, no_write, ssl_cert='', local_config=False):
     global __no_write
     __no_write = no_write
     if token is None:
         raise cli_exception.CliException('token is mandatory. please see neoload login --help.')
-    global __user_data_singleton
+
     __user_data_singleton = UserData.from_login(token, url)
+    if not __no_write:
+        __user_data_singleton.set_file(__local_file if local_config else CONFIG_FILE)
     __user_data_singleton.set_ssl_cert(ssl_cert)
-    __user_data_singleton.set_metadata_names_resolver(resolve_user_data_metadata_name)
     __compute_version_and_path()
     __save_user_data()
     return __user_data_singleton
 
-def resolve_user_data_metadata_name(user_data, key, value):
-    config_resolvenames = config_global.get_attr('status.resolvenames')
-    config_resolvenames = "" if config_resolvenames is None else str(config_resolvenames).lower()
-    if config_resolvenames == 'false':
-        return None
-
-    resolver = None
-    is_id = None
-    name = None
-    if key == 'result id':
-        name = value
-        resolver = Resolver("/test-results", rest_crud.base_endpoint_with_workspace)
-    elif key == 'settings id':
-        name = value
-        resolver = Resolver("/tests", rest_crud.base_endpoint_with_workspace)
-    elif key == 'workspace id':
-        name = value
-        resolver = Resolver("/workspaces", rest_crud.base_endpoint)
-        is_id = True
-    if resolver is not None:
-        if is_id is None:
-            is_id = tools.is_id(name)
-        entity = tools.get_named_or_id(name, is_id, resolver)
-        return entity["name"]
-    return None
 
 def get_front_url_by_private_entrypoint():
     response = rest_crud.get('/nlweb/rest/rest-api/url-api/v1/action/get-front-end-url')
@@ -81,7 +57,7 @@ def __compute_version_and_path():
     if get_nlweb_information() is False:
         file_storage = get_file_storage_from_swagger()
         front = get_front_url_by_private_entrypoint()
-        __user_data_singleton.set_url(front, file_storage, None)
+        UserData.get_instance().set_url(front, file_storage, None)
 
 
 def get_file_storage_from_swagger():
@@ -101,7 +77,7 @@ def get_nlweb_information():
             raise cli_exception.CliException(response.text)
         elif response.status_code == 200:
             json = response.json()
-            __user_data_singleton.set_url(json['front_url'], json['filestorage_url'], json['version'])
+            UserData.get_instance().set_url(json['front_url'], json['filestorage_url'], json['version'])
             return True
         else:
             return False
@@ -116,32 +92,55 @@ def get_nlweb_information():
 
 
 class UserData:
+    __instance = None
+
+    @staticmethod
+    def get_instance():
+        if UserData.__instance is None and os.path.exists(CONFIG_FILE):
+            with open(CONFIG_FILE, "r") as stream:
+                load = yaml.load(stream, Loader=yaml.BaseLoader)
+                loaded = UserData(desc=load)
+                loaded.file = CONFIG_FILE
+                UserData.__instance = loaded if loaded.token else None
+
+        return UserData.__instance
+
+    @staticmethod
+    def from_login(token: str, url: str):
+        UserData.__instance = UserData(token, url)
+        return UserData.__instance
+
+    @staticmethod
+    def clean():
+        UserData.__instance = None
+
     def __init__(self, token=None, url=None, desc=None):
         self.metadata = {}
-        self.resolve_func = None
+        self.resolved_ids = {}
+        self.file = None
         if desc:
             self.__dict__.update(desc)
         else:
             self.token = token
             self.url = url
 
-    @staticmethod
-    def from_dict(entries):
-        return UserData(desc=entries)
-
-    @staticmethod
-    def from_login(token: str, url: str):
-        return UserData(token, url)
-
     def __str__(self):
         token = '*' * (len(self.token) - 3) + self.token[-3:]
         metadata = ""
         for (key, value) in self.metadata.items():
             if value is not None:
-                name = None if self.resolve_func is None else self.resolve_func(self,key,value)
-                metadata += key + ": " + str(value) + (" ({})".format(name) if name is not None else "") + "\n"
+                metadata += key + ": " + str(value) + self.prettify_resolved(key, value) + "\n"
+        if self.file:
+            metadata += "\nThe configuration file is: " + os.path.realpath(self.file) + "\n"
         return "You are logged on " + self.url + " with token " + token + "\n\n" + metadata
 
+    def prettify_resolved(self, key, value):
+        resolved_map = self.resolved_ids.get(key)
+        if resolved_map:
+            resolved_value = resolved_map.get(str(value))
+            return ' ({})'.format(resolved_value) if resolved_value else ""
+        return ''
+
     def get_url(self):
         return self.url
 
@@ -171,33 +170,22 @@ class UserData:
         if ssl_cert:
             self.metadata['ssl certificate'] = ssl_cert
 
-    def set_metadata_names_resolver(self, resolve_func):
-        self.resolve_func = resolve_func
-
-
-def __load_user_data():
-    if os.path.exists(__config_file):
-        with open(__config_file, "r") as stream:
-            load = yaml.load(stream, Loader=yaml.BaseLoader)
-            ret = UserData.from_dict(load)
-            ret.set_metadata_names_resolver(resolve_user_data_metadata_name)
-            return ret
-
-    return None
-
-
-__user_data_singleton = __load_user_data()
+    def set_file(self, file):
+        self.file = file
 
 
 def get_ssl_cert():
-    return tools.ssl_cert_to_verify(__user_data_singleton.metadata.get('ssl certificate'))
+    return tools.ssl_cert_to_verify(UserData.get_instance().metadata.get('ssl certificate'))
 
 
 def __save_user_data():
     if not __no_write:
-        os.makedirs(__config_dir, exist_ok=True)
-        with open(__config_file, "w") as stream:
-            yaml.dump(__user_data_singleton.__dict__, stream)
+        instance = UserData.get_instance()
+        dest_file = os.path.abspath(instance.file or CONFIG_FILE)
+        config_dir = os.path.dirname(dest_file)
+        os.makedirs(config_dir, exist_ok=True)
+        with open(dest_file, "w") as stream:
+            yaml.dump(instance.__dict__, stream)
 
 
 def set_meta(key, value):
@@ -208,6 +196,16 @@ def set_meta(key, value):
     __save_user_data()
 
 
+def put_resolved_map(key, values, save=True):
+    if values is None:
+        get_user_data().resolved_ids.pop(key, None)
+    else:
+        get_user_data().resolved_ids[key] = {v: k for k, v in values.items()}
+
+    if save:
+        __save_user_data()
+
+
 def get_meta(key):
     result = get_user_data().metadata.get(key, None)
     if result == 'null':
